%global srcname ZODB

Name:           python-%{srcname}
Version:        5.4.0
Release:        4%{?dist}
Summary:        Zope Object Database and persistence

License:        ZPLv2.1
URL:            http://www.zodb.org/
Source0:        %pypi_source
# Work around a test suite bug
Patch0:         %{name}-testsuite.patch
BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python2dist(btrees)
BuildRequires:  python2dist(manuel)
BuildRequires:  python2dist(persistent)
BuildRequires:  python2dist(setuptools)
BuildRequires:  python2dist(six)
BuildRequires:  python2dist(transaction)
BuildRequires:  python2dist(zc.lockfile)
BuildRequires:  python2dist(zconfig)
BuildRequires:  python2dist(zodbpickle)
BuildRequires:  python2dist(zope.testing)
BuildRequires:  python2dist(zope.testrunner)

BuildRequires:  python3-devel
BuildRequires:  python3dist(btrees)
BuildRequires:  python3dist(manuel)
BuildRequires:  python3dist(persistent)
BuildRequires:  python3dist(j1m.sphinxautointerface)
BuildRequires:  python3dist(j1m.sphinxautozconfig)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(six)
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(transaction)
BuildRequires:  python3dist(zc.lockfile)
BuildRequires:  python3dist(zconfig)
BuildRequires:  python3dist(zodbpickle)
BuildRequires:  python3dist(zope.testing)
BuildRequires:  python3dist(zope.testrunner)

%global common_desc                                                \
The ZODB package provides a set of tools for using the Zope Object \
Database (ZODB).

%description
%{common_desc}

%package -n python2-%{srcname}
Summary:        Zope Object Database and persistence
Requires:       python2dist(btrees)
Requires:       python2dist(persistent)
Requires:       python2dist(setuptools)
Requires:       python2dist(six)
Requires:       python2dist(transaction)
Requires:       python2dist(zc.lockfile)
Requires:       python2dist(zconfig)
Requires:       python2dist(zodbpickle)

%{?python_provide:%python_provide python2-%{srcname}}

%description -n python2-%{srcname}
%{common_desc}

%package -n python3-%{srcname}
Summary:        Zope Object Database and persistence
Requires:       python3dist(btrees)
Requires:       python3dist(persistent)
Requires:       python3dist(setuptools)
Requires:       python3dist(six)
Requires:       python3dist(transaction)
Requires:       python3dist(zc.lockfile)
Requires:       python3dist(zconfig)
Requires:       python3dist(zodbpickle)

%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
%{common_desc}

%package doc
Summary:        Documentation for %{srcname}

%description doc
Documentation for %{srcname}.

%prep
%setup -q -c
%patch0

# Remove prebuilt egg
rm -fr %{srcname}-%{version}/src/%{srcname}.egg-info

# Prepare for a python3 build
cp -a %{srcname}-%{version} python3-%{srcname}-%{version}

%build
# Python 2 build
pushd %{srcname}-%{version}
%py2_build
popd

# Python 3 build
pushd python3-%{srcname}-%{version}
%py3_build

# Build the documentation
make -C doc html \
     SPHINXBUILD=%{_bindir}/sphinx-build-%{python3_version} \
     PYTHONPATH=$PWD/build/lib
rm doc/build/html/.buildinfo
popd

%install
# Python 3 install
pushd python3-%{srcname}-%{version}
%py3_install
popd
for bin in fsdump fsoids fsrefs fstail repozo; do
  mv %{buildroot}%{_bindir}/$bin %{buildroot}%{_bindir}/python3-${bin}
done

# Fix scripts
for script in \
  $(grep -l '^#!' %{buildroot}%{python3_sitelib}/%{srcname}/scripts/*.py); do
  sed 's,%{_bindir}/python,&3,;s,%{_bindir}/env python.*,%{_bindir}/python3,' \
    $script > $script.new
  touch -r $script $script.new
  mv -f $script.new $script
  chmod 0755 $script
done

# Python 2 install
pushd %{srcname}-%{version}
%py2_install

# Fix scripts
for script in \
  $(grep -l '^#!' %{buildroot}%{python2_sitelib}/%{srcname}/scripts/*.py); do
  sed 's,%{_bindir}/python,&2,;s,%{_bindir}/env python.*,%{_bindir}/python2,' \
    $script > $script.new
  touch -r $script $script.new
  mv -f $script.new $script
  chmod 0755 $script
done
popd

%check
# Python 2 tests
pushd %{srcname}-%{version}
%{__python2} setup.py test
popd

# Python 3 tests
pushd python3-%{srcname}-%{version}
%{__python3} setup.py test
popd

%files -n python2-%{srcname}
%license %{srcname}-%{version}/COPYRIGHT.txt %{srcname}-%{version}/LICENSE.txt
%doc %{srcname}-%{version}/CHANGES.rst
%{_bindir}/fsdump
%{_bindir}/fsoids
%{_bindir}/fsrefs
%{_bindir}/fstail
%{_bindir}/repozo
%{python2_sitelib}/%{srcname}*

%files -n python3-%{srcname}
%license %{srcname}-%{version}/COPYRIGHT.txt %{srcname}-%{version}/LICENSE.txt
%doc %{srcname}-%{version}/CHANGES.rst
%{_bindir}/python3-fsdump
%{_bindir}/python3-fsoids
%{_bindir}/python3-fsrefs
%{_bindir}/python3-fstail
%{_bindir}/python3-repozo
%{python3_sitelib}/%{srcname}*

%files doc
%doc python3-%{srcname}-%{version}/doc/build/html

%changelog
* Thu Sep 13 2018 Jerry James <loganjerry@gmail.com> - 5.4.0-4
- Build documentation again, in the -doc subpackage

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 5.4.0-2
- Rebuilt for Python 3.7

* Mon Mar 26 2018 Jerry James <loganjerry@gmail.com> - 5.4.0-1
- New upstream release

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Oct  7 2017 Jerry James <loganjerry@gmail.com> - 5.3.0-1
- New upstream release
- Skip doc building until new dependencies can be added to Fedora

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 5.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 5.1.1-2
- Rebuild for Python 3.6

* Sat Dec 10 2016 Jerry James <loganjerry@gmail.com> - 5.1.1-1
- New upstream release

* Tue Sep  6 2016 Jerry James <loganjerry@gmail.com> - 5.0.0-1
- New upstream release

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.3.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Fri Jun 10 2016 Jerry James <loganjerry@gmail.com> - 4.3.1-1
- New upstream release

* Wed Jun  1 2016 Jerry James <loganjerry@gmail.com> - 4.3.0-1
- New upstream release

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Feb  1 2016 Jerry James <loganjerry@gmail.com> - 4.2.0-3
- Comply with latest python packaging guidelines

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun  9 2015 Jerry James <loganjerry@gmail.com> - 4.2.0-1
- New upstream release

* Mon Jan 12 2015 Jerry James <loganjerry@gmail.com> - 4.1.0-1
- New upstream release

* Wed Aug  6 2014 Jerry James <loganjerry@gmail.com> - 4.0.1-1
- New upstream release

* Wed Jun 11 2014 Jerry James <loganjerry@gmail.com> - 4.0.0-1
- Initial RPM
